@@ -24,7 +24,7 @@ This is alpha software! Read the package README.
 package Chj::IO::Tempdir;
 @ISA="Chj::IO::Dir"; require Chj::IO::Dir;
 
-use strict;
+use strict; use warnings; use warnings FATAL => 'uninitialized';
 use Carp;
 use Errno qw(EEXIST EINTR);
 use overload
