@@ -84,7 +84,7 @@ use Chj::singlequote;
 # get the style
 sub run_tests_style { # "old" or "tap"
     if (my $rt= $ENV{RUN_TESTS}) {
-        ($rt=~ /old/i ? "old" :
+        ($rt=~ /(old|pod_snippets)/i ? "old" :
          #$rt=~ /(new|tap)/i ? "tap" :
          "tap")
     } else {
@@ -137,11 +137,15 @@ sub import {
             if (eval $code) {
                 # ok
             } else {
-                if ($ENV{RUN_TESTS}) {
-                    #carp "RUN_TESTS is set and we failed to $smallcode";
-                    require Test::More;
-                    Test::More::plan (skip_all=> "failed to $smallcode");
-                    exit 1; # necessary?
+                if (my $rt= $ENV{RUN_TESTS}) {
+                    if ($rt=~ /pod_snippets/i) {
+                        die "TEST use<$module> failed: $smallcode";
+                    } else {
+                        #carp "RUN_TESTS is set and we failed to $smallcode";
+                        require Test::More;
+                        Test::More::plan (skip_all=> "failed to $smallcode");
+                        exit 1; # necessary?
+                    }
                 } else {
                     die $@
                 }
@@ -424,8 +428,22 @@ sub run_tests_ {
         delete $$args{no};
     for (sort keys %$args) { warn "run_tests_: unknown argument '$_'" }
 
+    local $run_tests_style //= run_tests_style;
+
     local $|= 1;
 
+    style_switch +{
+        old=> sub {
+            print "==== run_tests in $run_tests_style style ====\n";
+        },
+        tap=> sub {
+            # if run_tests is called from perhaps_run_tests this was
+            # already done but can't count on that:
+            require Test::More;
+            import Test::More;
+        },
+    };
+
     my $stat= bless {success=>0, fail=>0}, "Chj::TEST::Result";
 
     my $packages= do {
@@ -458,21 +476,8 @@ sub run_tests_ {
 
 
 sub run_tests {
-    local $run_tests_style //= run_tests_style;
     my $packages= [@_];
-    style_switch +{
-        old=> sub {
-            print "==== run_tests in $run_tests_style style ====\n";
-            run_tests_ packages=> $packages;
-        },
-        tap=> sub {
-            # if run_tests is called from perhaps_run_tests this was
-            # already done but can't count on that:
-            require Test::More;
-            import Test::More;
-            run_tests_ packages=> $packages;
-        },
-    };
+    run_tests_ packages=> $packages;
 }
 
 # run tests for test suite:
