@@ -75,6 +75,7 @@ package FP::Ops;
                  string_le
                  string_gt
                  string_ge
+                 string
                  string_lc
                  string_uc
                  string_lcfirst
@@ -195,6 +196,10 @@ sub string_ge ($ $) {
     $_[0] ge $_[1]
 }
 
+sub string ($) {
+    "$_[0]"
+}
+
 sub string_lc ($) {
     @_==1 or die "need 1 argument";
     lc $_[0]
