@@ -522,13 +522,16 @@ sub eval_code {
       $Function::Parameters::VERSION ? "use Function::Parameters ':strict'" : "";
     my $use_tail=
       $Sub::Call::Tail::VERSION ? "use Sub::Call::Tail" : "";
+    my $use_autobox=
+      @FP::autobox::ISA ? "use FP::autobox" : "";
 
     my $prelude=
       "package ".&$in_package().";".
       "use strict; ".
        ($self->use_strict_vars ? "" : "no strict 'vars'; ").
        "$use_warnings; ".
-       "$use_method_signatures; $use_functional_parameters_; $use_tail; ";
+       "$use_method_signatures; $use_functional_parameters_; $use_tail; ".
+       "$use_autobox; ";
 
     if (my $lp= $maybe_lexical_persistence) {
         my $allcode=
